pub fn compile_dbc_target_plan(
effect_type: i32,
target_a: i32,
target_b: i32,
) -> Result<TargetPlan, TargetPlanError>Expand description
Translate TargetA/TargetB into operations without deciding which axes the runtime supports.
Errors
Returns an error when an effect type or implicit target selector is unknown.